@@ -15,9 +15,9 @@ our @EXPORT_OK = qw(
   blessed refaddr reftype weaken unweaken isweak
 
   dualvar isdual isvstring looks_like_number openhandle readonly set_prototype
-  set_subname subname tainted
+  tainted
 );
-our $VERSION    = "1.39_001";
+our $VERSION    = "1.39_002";
 $VERSION   = eval $VERSION;
 
 our @EXPORT_FAIL;
@@ -46,6 +46,13 @@ sub export_fail {
   @_;
 }
 
+# set_prototype has been moved to Sub::Util with a different interface
+sub set_prototype(&$)
+{
+  my ( $code, $proto ) = @_;
+  return Sub::Util::set_prototype( $proto, $code );
+}
+
 1;
 
 __END__
@@ -268,48 +275,6 @@ it if C<$prototype> is C<undef>. Returns the C<$code> reference itself.
 
     set_prototype \&foo, '$$';
 
-=head2 $code = set_subname( $name, $code )
-
-I<Since version 1.39_001.>
-
-Sets the name of the function given by the C<$code> reference. Returns the
-C<$code> reference itself. If the C<$name> is unqualified, the package of the
-caller is used to qualify it.
-
-    my $code = set_subname do_thing => sub { ... };
-
-This is useful for applying names to anonymous CODE references so that stack
-traces and similar situations, to give a useful name rather than having the
-default of C<__ANON__>. Note that this name is only used for this situation;
-the C<set_subname> will not install it into the symbol table; you will have to
-do that yourself if required.
-
-However, since the name is not used by perl except as the return value of
-C<caller>, for stack traces or similar, there is no actual requirement that
-the name be syntactically valid as a perl function name. This could be used to
-attach extra information that could be useful in debugging stack traces.
-
-This function was copied from C<Sub::Name::subname> and renamed to the naming
-convention of this module.
-
-=head2 $name = subname( $code )
-
-I<Since version 1.39_001.>
-
-Returns the name of the given C<$code> reference, if it has one. Normal named
-subs will give a fully-qualified name consisting of the package and the
-localname separated by C<::>. Anonymous code references will give C<__ANON__>
-as the localname. If a name has been set using C<set_subname>, this name will
-be returned instead.
-
-This function was inspired by C<sub_fullname> from L<Sub::Identify>. The
-remaining functions that C<Sub::Identify> implements can easily be emulated
-using regexp operations, such as
-
- sub get_code_info { return (subname $_[0]) =~ m/^(.+)::(.+?)$/ }
- sub sub_name      { return (get_code_info $_[0])[0] }
- sub stash_name    { return (get_code_info $_[0])[1] }
-
 =head2 $t = tainted( $var )
 
 Return true if C<$var> is tainted.
@@ -365,10 +330,6 @@ Copyright (c) 1999 Tuomas J. Lukka <lukka@iki.fi>. All rights reserved.
 This program is free software; you can redistribute it and/or modify it
 under the same terms as perl itself.
 
-Additionally C<set_subname> which is
-
-Matthijs van Duin <xmath@cpan.org>
-
 Copyright (C) 2004, 2008  Matthijs van Duin.  All rights reserved.
 Copyright (C) 2014 cPanel Inc.  All rights reserved.
 This program is free software; you can redistribute it and/or modify
